@@ -203,3 +203,11 @@ rbind_fill <- function(x, y) {
     }
     return(rbind(x, y))
 }
+
+#' Get information on TBB library
+#' @keywords internal
+#' @export
+info_tbb <- function() {
+    list("enabled" = cpp_tbb_enabled(),
+         "max_threads" = cpp_get_max_thread())
+}
