@@ -44,6 +44,11 @@ test_that("multi-word dictionary keys are counted correctly", {
     expect_equal(as.vector(dfm_case_asis_glob[, "oceans"]), c(2, 0, 0, 0, 0, 0))
     expect_equal(as.vector(dfm_case_asis_glob[, "team"]), c(0, 0, 2, 1, 0, 0))
     
+    expect_message(
+        tokens_lookup(toks, dict_mw_fixed, verbose = TRUE),
+        'tokens_lookup() changed', fixed = TRUE
+    )
+    
 })
 
 test_that("entirely single-word dictionary keys are counted correctly", {
